# Documentation

To serve the documentation locally, you need to:

1. Install the dependencies
    ```sh
    pip install "sereto[docs]"
    ```

2. Start a local client
    ```sh
    mkdocs serve
    ```

3. Open the URL presented in the terminal as the output of the previous command, typically [http://127.0.0.1:8000](http://127.0.0.1:8000/).
